diff --git a/src/org/opensha2/mfd/Mfds.java b/src/org/opensha2/mfd/Mfds.java
index 358bf23bc5c0d51dd4be18e8c0682cda5c03f77d..94b484184cfaa22746860ab50d4c691c5c2f5443 100644
--- a/src/org/opensha2/mfd/Mfds.java
+++ b/src/org/opensha2/mfd/Mfds.java
@@ -325,11 +325,11 @@ public final class Mfds {
    * method returns the Poisson probability of occurence over the specified time
    * period.
    * @param rate (annual) of occurence of some event
    * @param time period of interest
    * @return the Poisson probability of occurrence in the specified {@code time}
    */
-  public static double rateToProb(double rate, double time) {
-    return 1 - exp(-rate * time);
+  public static double rateToProb(double rate, double timespan) {
+    return 1 - exp(-rate * timespan);
   }
 
   /**
@@ -337,11 +337,11 @@ public final class Mfds {
    * specified time period, method returns the annual rate of occurrence of that
    * event.
    * @param P the Poisson probability of an event's occurrence
    * @param time period of interest
    * @return the annnual rate of occurrence of the event
    */
-  public static double probToRate(double P, double time) {
-    return -log(1 - P) / time;
+  public static double probToRate(double P, double timespan) {
+    return -log(1 - P) / timespan;
   }
 
   /**
@@ -325,11 +325,11 @@ public final class Mfds {
    * period.
    * @param rate (annual) of occurence of some event
-   * @param time period of interest
+   * @param timespan of interest
    * @return the Poisson probability of occurrence in the specified {@code time}
    */
@@ -337,11 +337,11 @@ public final class Mfds {
    * event.
    * @param P the Poisson probability of an event's occurrence
-   * @param time period of interest
+   * @param timespan of interest
    * @return the annnual rate of occurrence of the event
    */